/************************************************************************
 * so.h -- routines for reading the parameters to compiled shader files
 *         for the BMRT.
 *
 * The Blue Moon Rendering Tools package is:
 * (c) Copyright 1990-1992 by Larry I. Gritz.  All rights reserved.
 *
 * The RenderMan (R) Interface Procedures and RIB Protocol are:
 *      Copyright 1988, 1989, Pixar.  All rights reserved.
 * RenderMan (R) is a registered trademark of Pixar.
 *
 * this file last updated 2 November 1994
 ************************************************************************/

#ifndef SO_H
#define SO_H

#ifdef __cplusplus
extern "C" {
#endif


typedef enum {
    SO_TYPE_UNKNOWN,
    SO_TYPE_POINT,
    SO_TYPE_COLOR,
    SO_TYPE_SCALAR,
    SO_TYPE_STRING,
    SO_TYPE_SURFACE,
    SO_TYPE_LIGHT,
    SO_TYPE_DISPLACEMENT,
    SO_TYPE_VOLUME,
    SO_TYPE_TRANSFORMATION,
    SO_TYPE_IMAGER
    } SO_TYPE;

typedef enum {
    SO_STOR_UNKNOWN,
    SO_STOR_CONSTANT,
    SO_STOR_VARIABLE,
    SO_STOR_TEMPORARY,
    SO_STOR_PARAMETER,
    SO_STOR_GSTATE
    } SO_STORAGE;

typedef enum {
    SO_DETAIL_UNKNOWN,
    SO_DETAIL_VARYING,
    SO_DETAIL_UNIFORM
    } SO_DETAIL;


#ifndef _SHADECON_
#define _SHADECON_
typedef struct {
    float	xval;
    float	yval;
    float	zval;
    } POINT;

typedef float SCALAR;
#endif


typedef struct SOvissymdef {
    char *svd_name;
    SO_TYPE svd_type;
    SO_STORAGE svd_storage;
    SO_DETAIL svd_detail;
    char *svd_spacename;
    union {
	POINT	*pointval;
	SCALAR	*scalarval;
	char	*stringval;
    } svd_default;
    union svd_defaultvalu {
	POINT	svd_pointval;
	SCALAR	svd_scalarval;
    } svd_defaultval;
    unsigned svd_valisvalid : 1;
} SO_VISSYMDEF;



#define NULL_SOVISSYMDEF NULL


extern void SO_SetPath(char *path);
extern char *SO_GetPath(void);
extern int SO_SetShader(char *name);
extern char *SO_GetName(void);
extern SO_TYPE SO_GetType(void);
extern int SO_GetNArgs(void);
extern SO_VISSYMDEF *SO_GetArgByName(char *name);
extern SO_VISSYMDEF *SO_GetArgById(int id);
extern void SO_EndShader(void);
extern char *SO_TypetoStr(SO_TYPE type);
extern char *SO_StortoStr(SO_STORAGE storage);
extern char *SO_DetailtoStr(SO_DETAIL detail);


#ifdef __cplusplus
}
#endif

#endif /* SO_H */
